import React, { useState } from 'react'
import Taro from '@tarojs/taro'
import { useSelector } from 'react-redux'
import { Image } from '@tarojs/components'
import AuthRole from '@/components/auth/AuthRole'
import Poster from '@/components/Poster'
import { ROLE_CODE } from '@/constants/user'
import './index.scss'

export default function DetailBottom (props) {
  const { Info = {}, poster } = props

  // 当前推荐置业
  const { consultant } = useSelector(s => s.system)
  const [showPoster, setShowPoster] = useState(false)

  const handleCall = () => {
    if (Info.tel) {
      Taro.makePhoneCall({ phoneNumber: Info.tel })
      return
    }

    Taro.showToast({ title: '暂无联系电话', icon: 'none' })
  }

  const handleChat = () => {
    // TODO 订阅消息

    if (consultant?.id) {
      Taro.navigateTo({
        url: `/pages/chat/detail?targetPerson=${consultant.id}}`
      })
    } else {
      Taro.navigateTo({
        url: `/pages/index/buildingPropertyConsultant/index?buldingId=${Info?.buildingId}`
      })
    }
  }

  const handleRecommender = () => {
    const params = `buildingId=${Info?.buildingId}&buildingName=${Info?.buildingName}`

    Taro.navigateTo({
      url: `/pages/mine/recommendUser/index?${params}`
    })
  }

  return (
    <view>
      <view className='components DetailBottom flex-h'>
        <view className='Item' onClick={() => setShowPoster(true)}>
          <Image mode='heightFix' src={require('@/assets/buildingDetail-icon3.png')}></Image>
          <text>一键海报</text>
        </view>
        <view className='Item'>
          <Image mode='heightFix' src={require('@/assets/buildingDetail-icon1.png')}></Image>
          <text>一键带看</text>
        </view>
        <AuthRole role={ROLE_CODE.CONSULTANT}>
          <view className='Item' onClick={handleRecommender}>
            <Image mode='heightFix' src={require('@/assets/buildingDetail-icon2.png')}></Image>
            <text>一键推荐</text>
          </view>
        </AuthRole>
        <view className='flex-item'></view>
        <view className='Btn'>
          <text onClick={handleChat}>一键咨询</text>
          <text className='active' onClick={handleCall}>一键电话</text>
        </view>
      </view>

      <Poster
        show={showPoster}
        dataSource={poster}
        onClose={() => setShowPoster(false)}
        onSuccess={() => setShowPoster(false)}
      />
    </view>
  )
}
